@@ -2,7 +2,7 @@ use strict;
 use warnings;
 package MetaCPAN::Client;
 # ABSTRACT: A comprehensive, DWIM-featured client to the MetaCPAN API
-$MetaCPAN::Client::VERSION = '2.001000';
+$MetaCPAN::Client::VERSION = '2.002000';
 use Moo;
 use Carp;
 use Ref::Util qw< is_arrayref is_hashref >;
@@ -172,6 +172,26 @@ sub download_url {
     return $self->_get( 'download_url', $module );
 }
 
+sub autocomplete {
+    my $self = shift;
+    my $q    = shift;
+
+    my $res;
+
+    eval {
+        $res = $self->fetch("/search/autocomplete?q=$q");
+        1;
+
+    } or do {
+        warn $@;
+        return [];
+    };
+
+    return [
+        map { $_->{fields} } @{ $res->{hits}{hits} }
+    ];
+}
+
 ###
 
 sub _get {
@@ -350,7 +370,7 @@ MetaCPAN::Client - A comprehensive, DWIM-featured client to the MetaCPAN API
 
 =head1 VERSION
 
-version 2.001000
+version 2.002000
 
 =head1 SYNOPSIS
 
@@ -491,6 +511,14 @@ on a given module, returned as L<MetaCPAN::Client::ResultSet>.
 
 Alias to C<reverse_dependencies> described above.
 
+=head2 autocomplete
+
+    my $ac = $mcpan->autocomplete('Danc');
+
+Call the search/autocomplete endpoint with a query string.
+
+Returns an array reference.
+
 =head2 recent
 
     my $recent = $mcpan->recent(10);
